@@ -16,8 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """
-This module contains a Salesforce Hook which allows you to connect to your Salesforce instance,
-retrieve data from it, and write that data to a file for other uses.
+Connect to your Salesforce instance, retrieve data from it, and write that data to a file for other uses.
 
 .. note:: this hook also relies on the simple_salesforce package:
       https://github.com/simple-salesforce/simple-salesforce
@@ -27,14 +26,16 @@ from __future__ import annotations
 import logging
 import time
 from functools import cached_property
-from typing import Any, Iterable
+from typing import TYPE_CHECKING, Any, Iterable
 
-import pandas as pd
 from requests import Session
 from simple_salesforce import Salesforce, api
 
 from airflow.hooks.base import BaseHook
 
+if TYPE_CHECKING:
+    import pandas as pd
+
 log = logging.getLogger(__name__)
 
 
@@ -180,6 +181,7 @@ class SalesforceHook(BaseHook):
     def describe_object(self, obj: str) -> dict:
         """
         Get the description of an object from Salesforce.
+
         This description is the object's schema and
         some extra metadata that Salesforce stores for each object.
 
@@ -204,6 +206,7 @@ class SalesforceHook(BaseHook):
     def get_object_from_salesforce(self, obj: str, fields: Iterable[str]) -> dict:
         """
         Get all instances of the `object` from Salesforce.
+
         For each model, only get the fields specified in fields.
 
         All we really do underneath the hood is run:
@@ -239,6 +242,8 @@ class SalesforceHook(BaseHook):
         # between 0 and 10 are turned into timestamps
         # if the column cannot be converted,
         # just return the original column untouched
+        import pandas as pd
+
         try:
             column = pd.to_datetime(column)
         except ValueError:
@@ -354,6 +359,8 @@ class SalesforceHook(BaseHook):
             to the resulting data that marks when the data was fetched from Salesforce. Default: False
         :return: the dataframe.
         """
+        import pandas as pd
+
         # this line right here will convert all integers to floats
         # if there are any None/np.nan values in the column
         # that's because None/np.nan cannot exist in an integer column
